@@ -38,7 +38,7 @@ def ebay_timestamp_string(datetime_obj):
         'hour': datetime_obj.hour,
         'minute': datetime_obj.minute,
         'second': datetime_obj.second,
-        'millisecond': datetime_obj.microsecond * 1000
+        'millisecond': datetime_obj.microsecond# don't need to x1000 as we're omitting the zero-padding
     }
 
 
@@ -84,8 +84,8 @@ class NotificationHandler(object):
         http://developer.ebay.com/DevZone/XML/docs/WebHelp/wwhelp/wwhimpl/common/html/wwhelp.htm?context=eBay_XML_API&file=WorkingWithNotifications-Receiving_Platform_Notifications.html
         """
         
-        floattime = time.mktime(message.Timestamp.timetuple())
         timestamp_str = ebay_timestamp_string(message.Timestamp)
+        floattime = time.mktime(message.Timestamp.timetuple())
         print '%s -> %s' % (message.Timestamp, timestamp_str)
         if not settings.DEBUG:
             # check timestamp is within 10 minutes of current time
@@ -101,9 +101,10 @@ class NotificationHandler(object):
             conf_section = 'sandbox_keys'
         else:
             conf_section = 'production_keys'
+        print conf_section
         m.update(ebaysuds_config.get(conf_section, 'app_id'))
         m.update(ebaysuds_config.get(conf_section, 'cert_id'))
-        computed_hash = base64.standard_b64encode(m.hexdigest())
+        computed_hash = base64.standard_b64encode(m.digest())
         if computed_hash != signature:
             raise InvalidSignature("%s != %s" % (computed_hash, signature))
 
